bayespy.inference.vmp.nodes.gaussian.GaussianARDDistribution.compute_moments_and_cgf
====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianARDDistribution.compute_moments_and_cgf